@@ -10,8 +10,8 @@ import seaborn as sns
 
 
 # need to calculate only on the upper triangle because the matrices are symmetric
-def calculate_chi_squared_value(alleles_amount, population_amount_, alleles_probabilities,
-                                observed_probabilities, correction, cutoff):
+def _calculate_chi_squared_value(alleles_amount, population_amount_, alleles_probabilities,
+                                 observed_probabilities, correction, cutoff):
     value = 0.0
     amount_of_small_expected_ = 0
     for row in range(alleles_amount):
@@ -30,14 +30,14 @@ def calculate_chi_squared_value(alleles_amount, population_amount_, alleles_prob
     return value, amount_of_small_expected_
 
 
-def run_experiment(alleles_count, population_amount, alleles_probabilities,
-                   observed_probabilities, correction, var_obs, index_to_allele_, should_save_csv_, cutoff_value_):
-    chi_squared_stat, amount_of_small_expected = calculate_chi_squared_value(alleles_amount=alleles_count,
-                                                                             population_amount_=population_amount,
-                                                                             alleles_probabilities=alleles_probabilities,
-                                                                             observed_probabilities=observed_probabilities,
-                                                                             correction=correction,
-                                                                             cutoff=cutoff_value_)
+def _run_experiment(alleles_count, population_amount, alleles_probabilities,
+                    observed_probabilities, correction, var_obs, index_to_allele_, should_save_csv_, cutoff_value_):
+    chi_squared_stat, amount_of_small_expected = _calculate_chi_squared_value(alleles_amount=alleles_count,
+                                                                              population_amount_=population_amount,
+                                                                              alleles_probabilities=alleles_probabilities,
+                                                                              observed_probabilities=observed_probabilities,
+                                                                              correction=correction,
+                                                                              cutoff=cutoff_value_)
     couples_amount = (alleles_count * (alleles_count + 1)) / 2 - 1
     dof = couples_amount - amount_of_small_expected
 
@@ -103,12 +103,12 @@ def full_algorithm(file_path,
      [first allele, second allele, observed, expected, variance] is saved (named 'alleles_data.csv')
     and if it's a string then a csv with the given string name is saved.
     :param should_save_plot: (optional, default value is False) Either boolean or string, if it's True then
-    a png containing 2 bar plots is saved (named 'alleles_barplot.png') for each allele showing its chi squared statistic over degrees of freedom
-    (summing over the observations only associated with this allele) and -log_10(p_value).
-    If it's a string then a csv with the given string name is saved.
+    an image containing 2 bar plots is saved (named 'alleles_barplot.png') for each allele showing its chi squared statistic over degrees of freedom
+    (summing over the observations only associated with this allele) and -log_10(p_value). If it's a string and ends with '.pdf' then the plot is saved in pdf format.
+    Otherwise, it's saved in png format.
+    If it's a string then a png with the given string name is saved.
     :param title: (optional, default value is '') A string that will be the title of the plot.
-    :return: p-value (float), Chi-Squared statistic (float), degrees of freedom (integer). also saves a csv.
-    with columns: first allele, second allele, observed, variance:
+    :return: p-value (float), Chi-Squared statistic (float), degrees of freedom (integer).
     """
     id_to_index = {}
     allele_to_index = {}
@@ -225,20 +225,20 @@ def full_algorithm(file_path,
                     var_value += (a - mean_value) ** 2
                 var_obs[i, j] = var_value
 
-    p_value, chi_squared, dof = run_experiment(alleles_count=alleles_count,
-                                               population_amount=population_amount,
-                                               alleles_probabilities=alleles_probabilities,
-                                               observed_probabilities=observed_probabilities,
-                                               correction=correction,
-                                               var_obs=var_obs,
-                                               index_to_allele_=index_to_allele,
-                                               should_save_csv_=should_save_csv,
-                                               cutoff_value_=cutoff_value)
+    p_value, chi_squared, dof = _run_experiment(alleles_count=alleles_count,
+                                                population_amount=population_amount,
+                                                alleles_probabilities=alleles_probabilities,
+                                                observed_probabilities=observed_probabilities,
+                                                correction=correction,
+                                                var_obs=var_obs,
+                                                index_to_allele_=index_to_allele,
+                                                should_save_csv_=should_save_csv,
+                                                cutoff_value_=cutoff_value)
 
     if should_save_plot:
         # save a bar plot showing for each allele its deviation from HWE
         # couples_amount = int((alleles_count * (alleles_count + 1)) / 2 - 1)
-        df = pd.DataFrame(index=range(alleles_count), columns=['Alleles', 'Normalized Statistic', '-log_10(p_value)'])
+        df = pd.DataFrame(index=range(alleles_count), columns=['Alleles', 'Normalized statistic', '-log_10(p_value)'])
         logs_list = ['s' for _ in range(alleles_count)]
         p_values = [0.0 for _ in range(alleles_count)]
         for i in range(alleles_count):
@@ -288,10 +288,10 @@ def full_algorithm(file_path,
                 if p_values[i] == 0.0:
                     df.loc[i, '-log_10(p_value)'] = max_log
 
-        # sort dataframe according to p_values and take the smallest 20 statistics.
+        # sort dataframe according to p_values and take the smallest 10 statistics.
         df = df.loc[df['-log_10(p_value)'] != 's']
-        df = df.sort_values('Normalized statistic', ascending=False).head(min(alleles_count, 20))
-        # we need to update the log p-values (some may be infinite, so we set them to the max value from the 20)
+        df = df.sort_values('Normalized statistic', ascending=False).head(min(alleles_count, 10))
+        # we need to update the log p-values (some may be infinite, so we set them to the max value from the 10)
 
         # plot the dataframe into 2 bar plots
         # fig, axes = plt.subplots(1, 2)
@@ -310,7 +310,7 @@ def full_algorithm(file_path,
         # move ticks to the right
 
         # plt.subplot(1, 2, 2)
-        fig = plt.figure()
+        # fig = plt.figure()
 
         # making a scatter plot with color bar
         sns.set_style('white')
@@ -324,6 +324,7 @@ def full_algorithm(file_path,
         # cbar.ax.tick_params(labelsize=15)
         cbar.ax.tick_params(labelsize=5)
         cbar.set_label('-log_10(p_value)', fontsize=7)
+        cbar.set_label('-log_10(p_value)')
         # removing the points from the color bar
         plot.remove()
         if df['-log_10(p_value)'].nunique() == 1:
@@ -338,19 +339,19 @@ def full_algorithm(file_path,
         # fig.tight_layout()
 
         # take care of the font sizes
-        # ax.set_xlabel('Normalized statistic', fontsize=18)
         ax.set_xlabel('Normalized statistic', fontsize=7)
-        # ax.set_ylabel('Alleles', fontsize=18)
+        # ax.set_xlabel('Normalized statistic')
         ax.set_ylabel('Alleles', fontsize=7)
-        # ax.tick_params(labelsize=15)
+        # ax.set_ylabel('Alleles')
         ax.tick_params(labelsize=5)
+        # ax.tick_params(labelsize=5)
         if isinstance(should_save_plot, str):
             file_name = should_save_plot
         else:
             file_name = 'alleles_barplot'
         if title:
-            # plt.title(title, fontsize=20)
             plt.title(title, fontsize=8)
+            # plt.title(title)
         # check whether to save in pdf format or other formats
         if file_name.endswith('.pdf'):
             plt.savefig(file_name, format='pdf', bbox_inches="tight")
